==> dojo-1.9.4.tgz: package/cldr/nls/zh/japanese.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yyyyMMMEd": "Gy年M月d日E",
	"field-dayperiod": "上午/下午",
	"field-minute": "分钟",
	"dateFormatItem-MMMEd": "M月d日E",
	"dateTimeFormat-full": "{1} {0}",
	"field-day-relative+-1": "昨天",
	"dateFormatItem-hms": "ah:mm:ss",
	"field-day-relative+-2": "前天",
	"field-weekday": "星期",
	"dateFormatItem-MMM": "LLL",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Gy": "Gy年",
	"dateTimeFormat-medium": "{1} {0}",
	"field-era": "时期",
	"field-hour": "小时",
	"dateFormatItem-y": "Gy年",
	"dateFormatItem-yyyy": "Gy年",
	"dateFormatItem-Ed": "d日E",
	"field-day-relative+0": "今天",
	"field-day-relative+1": "明天",
	"eraAbbr": [
		"大化 (645–650)",
		"白雉 (650–671)",
		"白凤 (672–686)",
		"朱鸟 (686–701)",
		"大宝 (701–704)",
		"庆云 (704–708)",
		"和铜 (708–715)",
		"灵龟 (715–717)",
		"养老 (717–724)",
		"神龟 (724–729)",
		"天平 (729–749)",
		"天平感宝 (749–749)",
		"天平胜宝 (749–757)",
		"天平宝字 (757–765)",
		"天平神护 (765–767)",
		"神护景云 (767–770)",
		"宝龟 (770–780)",
		"天应 (781–782)",
		"延历 (782–806)",
		"大同 (806–810)",
		"弘仁 (810–824)",
		"天长 (824–834)",
		"承和 (834–848)",
		"嘉祥 (848–851)",
		"仁寿 (851–854)",
		"齐衡 (854–857)",
		"天安 (857–859)",
		"贞观 (859–877)",
		"元庆 (877–885)",
		"仁和 (885–889)",
		"宽平 (889–898)",
		"昌泰 (898–901)",
		"延喜 (901–923)",
		"延长 (923–931)",
		"承平 (931–938)",
		"天庆 (938–947)",
		"天历 (947–957)",
		"天德 (957–961)",
		"应和 (961–964)",
		"康保 (964–968)",
		"安和 (968–970)",
		"天禄 (970–973)",
		"天延 (973–976)",
		"贞元 (976–978)",
		"天元 (978–983)",
		"永观 (983–985)",
		"宽和 (985–987)",
		"永延 (987–989)",
		"永祚 (989–990)",
		"正历 (990–995)",
		"长德 (995–999)",
		"长保 (999–1004)",
		"宽弘 (1004–1012)",
		"长和 (1012–1017)",
		"宽仁 (1017–1021)",
		"治安 (1021–1024)",
		"万寿 (1024–1028)",
		"长元 (1028–1037)",
		"长历 (1037–1040)",
		"长久 (1040–1044)",
		"宽德 (1044–1046)",
		"永承 (1046–1053)",
		"天喜 (1053–1058)",
		"康平 (1058–1065)",
		"治历 (1065–1069)",
		"延久 (1069–1074)",
		"承保 (1074–1077)",
		"正历 (1077–1081)",
		"永保 (1081–1084)",
		"应德 (1084–1087)",
		"宽治 (1087–1094)",
		"嘉保 (1094–1096)",
		"永长 (1096–1097)",
		"承德 (1097–1099)",
		"康和 (1099–1104)",
		"长治 (1104–1106)",
		"嘉承 (1106–1108)",
		"天仁 (1108–1110)",
		"天永 (1110–1113)",
		"永久 (1113–1118)",
		"元永 (1118–1120)",
		"保安 (1120–1124)",
		"天治 (1124–1126)",
		"大治 (1126–1131)",
		"天承 (1131–1132)",
		"长承 (1132–1135)",
		"保延 (1135–1141)",
		"永治 (1141–1142)",
		"康治 (1142–1144)",
		"天养 (1144–1145)",
		"久安 (1145–1151)",
		"仁平 (1151–1154)",
		"久寿 (1154–1156)",
		"保元 (1156–1159)",
		"平治 (1159–1160)",
		"永历 (1160–1161)",
		"应保 (1161–1163)",
		"长宽 (1163–1165)",
		"永万 (1165–1166)",
		"仁安 (1166–1169)",
		"嘉应 (1169–1171)",
		"承安 (1171–1175)",
		"安元 (1175–1177)",
		"治承 (1177–1181)",
		"养和 (1181–1182)",
		"寿永 (1182–1184)",
		"元历 (1184–1185)",
		"文治 (1185–1190)",
		"建久 (1190–1199)",
		"正治 (1199–1201)",
		"建仁 (1201–1204)",
		"元久 (1204–1206)",
		"建永 (1206–1207)",
		"承元 (1207–1211)",
		"建历 (1211–1213)",
		"建保 (1213–1219)",
		"承久 (1219–1222)",
		"贞应 (1222–1224)",
		"元仁 (1224–1225)",
		"嘉禄 (1225–1227)",
		"安贞 (1227–1229)",
		"宽喜 (1229–1232)",
		"贞永 (1232–1233)",
		"天福 (1233–1234)",
		"文历 (1234–1235)",
		"嘉祯 (1235–1238)",
		"历仁 (1238–1239)",
		"延应 (1239–1240)",
		"仁治 (1240–1243)",
		"宽元 (1243–1247)",
		"宝治 (1247–1249)",
		"建长 (1249–1256)",
		"康元 (1256–1257)",
		"正嘉 (1257–1259)",
		"正元 (1259–1260)",
		"文应 (1260–1261)",
		"弘长 (1261–1264)",
		"文永 (1264–1275)",
		"建治 (1275–1278)",
		"弘安 (1278–1288)",
		"正应 (1288–1293)",
		"永仁 (1293–1299)",
		"正安 (1299–1302)",
		"干元 (1302–1303)",
		"嘉元 (1303–1306)",
		"德治 (1306–1308)",
		"延庆 (1308–1311)",
		"应长 (1311–1312)",
		"正和 (1312–1317)",
		"文保 (1317–1319)",
		"元应 (1319–1321)",
		"元亨 (1321–1324)",
		"正中 (1324–1326)",
		"嘉历 (1326–1329)",
		"元德 (1329–1331)",
		"元弘 (1331–1334)",
		"建武 (1334–1336)",
		"延元 (1336–1340)",
		"兴国 (1340–1346)",
		"正平 (1346–1370)",
		"建德 (1370–1372)",
		"文中 (1372–1375)",
		"天授 (1375–1379)",
		"康历 (1379–1381)",
		"弘和 (1381–1384)",
		"元中 (1384–1392)",
		"至德 (1384–1387)",
		"嘉庆 (1387–1389)",
		"康应 (1389–1390)",
		"明德 (1390–1394)",
		"应永 (1394–1428)",
		"正长 (1428–1429)",
		"永享 (1429–1441)",
		"嘉吉 (1441–1444)",
		"文安 (1444–1449)",
		"宝德 (1449–1452)",
		"享德 (1452–1455)",
		"康正 (1455–1457)",
		"长禄 (1457–1460)",
		"宽正 (1460–1466)",
		"文正 (1466–1467)",
		"应仁 (1467–1469)",
		"文明 (1469–1487)",
		"长享 (1487–1489)",
		"延德 (1489–1492)",
		"明应 (1492–1501)",
		"文龟 (1501–1504)",
		"永正 (1504–1521)",
		"大永 (1521–1528)",
		"享禄 (1528–1532)",
		"天文 (1532–1555)",
		"弘治 (1555–1558)",
		"永禄 (1558–1570)",
		"元龟 (1570–1573)",
		"天正 (1573–1592)",
		"文禄 (1592–1596)",
		"庆长 (1596–1615)",
		"元和 (1615–1624)",
		"宽永 (1624–1644)",
		"正保 (1644–1648)",
		"庆安 (1648–1652)",
		"承应 (1652–1655)",
		"明历 (1655–1658)",
		"万治 (1658–1661)",
		"宽文 (1661–1673)",
		"延宝 (1673–1681)",
		"天和 (1681–1684)",
		"贞享 (1684–1688)",
		"元禄 (1688–1704)",
		"宝永 (1704–1711)",
		"正德 (1711–1716)",
		"享保 (1716–1736)",
		"元文 (1736–1741)",
		"宽保 (1741–1744)",
		"延享 (1744–1748)",
		"宽延 (1748–1751)",
		"宝历 (1751–1764)",
		"明和 (1764–1772)",
		"安永 (1772–1781)",
		"天明 (1781–1789)",
		"宽政 (1789–1801)",
		"享和 (1801–1804)",
		"文化 (1804–1818)",
		"文政 (1818–1830)",
		"天保 (1830–1844)",
		"弘化 (1844–1848)",
		"嘉永 (1848–1854)",
		"安政 (1854–1860)",
		"万延 (1860–1861)",
		"文久 (1861–1864)",
		"元治 (1864–1865)",
		"庆应 (1865–1868)",
		"明治",
		"大正",
		"昭和",
		"平成"
	],
	"field-day-relative+2": "后天",
	"dateFormatItem-GyMMMd": "Gy年M月d日",
	"dateFormat-long": "Gy年M月d日",
	"field-zone": "时区",
	"dateFormatItem-Hm": "HH:mm",
	"field-week-relative+-1": "上周",
	"dateFormat-medium": "Gy年M月d日",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "明年",
	"field-year-relative+-1": "去年",
	"dateFormatItem-ms": "mm:ss",
	"dateFormatItem-yyyyQQQQ": "Gy年QQQQ",
	"field-year": "年",
	"dateTimeFormat-long": "{1} {0}",
	"field-week": "周",
	"dateFormatItem-yyyyMd": "Gy-MM-dd",
	"dateFormatItem-yyyyMMMd": "Gy年M月d日",
	"dateFormatItem-yyyyMEd": "Gy-M-d（E）",
	"dateFormatItem-MMMd": "M月d日",
	"field-week-relative+0": "本周",
	"field-week-relative+1": "下周",
	"field-month-relative+0": "本月",
	"dateFormatItem-H": "H时",
	"field-month": "月",
	"field-month-relative+1": "下个月",
	"dateFormatItem-M": "M月",
	"field-second": "秒钟",
	"dateFormatItem-GyMMMEd": "Gy年M月d日E",
	"dateFormatItem-GyMMM": "Gy年M月",
	"field-day": "日",
	"dateFormatItem-MEd": "M-dE",
	"dateFormatItem-yyyyQQQ": "Gy年第Q季度",
	"dateFormatItem-hm": "ah:mm",
	"dateFormat-short": "Gyy-MM-dd",
	"dateFormatItem-yyyyM": "Gy-MM",
	"dateFormat-full": "Gy年M月d日EEEE",
	"dateFormatItem-Md": "M-d",
	"dateFormatItem-yyyyMMM": "Gy年M月",
	"dateFormatItem-d": "d日",
	"field-month-relative+-1": "上个月",
	"dateFormatItem-h": "ah时"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/zh/japanese.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "现在",
	"field-weekday": "工作日",
	"field-wed-relative+0": "本周三",
	"field-wed-relative+1": "下周三",
	"dateFormatItem-GyMMMEd": "Gy年M月d日E",
	"dateFormatItem-MMMEd": "M月d日E",
	"field-tue-relative+-1": "上周二",
	"dateFormat-long": "Gy年M月d日",
	"field-fri-relative+-1": "上周五",
	"field-wed-relative+-1": "上周三",
	"dateFormatItem-yyyyQQQ": "Gy年第Q季度",
	"dateTimeFormat-medium": "{1} {0}",
	"dateFormat-full": "Gy年M月d日EEEE",
	"dateFormatItem-yyyyMEd": "Gy-M-d（E）",
	"field-thu-relative+-1": "上周四",
	"dateFormatItem-Md": "M-d",
	"field-era": "纪元",
	"field-year": "年",
	"field-hour": "小时",
	"field-sat-relative+0": "本周六",
	"field-sat-relative+1": "下周六",
	"field-day-relative+0": "今天",
	"field-day-relative+1": "明天",
	"field-thu-relative+0": "本周四",
	"dateFormatItem-GyMMMd": "Gy年M月d日",
	"field-day-relative+2": "后天",
	"field-thu-relative+1": "下周四",
	"dateFormatItem-H": "H时",
	"dateFormatItem-Gy": "Gy年",
	"dateFormatItem-yyyyMMMEd": "Gy年M月d日E",
	"dateFormatItem-M": "M月",
	"dateFormatItem-yyyyMMM": "Gy年M月",
	"dateFormatItem-yyyyMMMd": "Gy年M月d日",
	"field-sun-relative+0": "本周日",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "下周日",
	"eraAbbr": [
		"大化 (645–650)",
		"白雉 (650–671)",
		"白凤 (672–686)",
		"朱鸟 (686–701)",
		"大宝 (701–704)",
		"庆云 (704–708)",
		"和铜 (708–715)",
		"灵龟 (715–717)",
		"养老 (717–724)",
		"神龟 (724–729)",
		"天平 (729–749)",
		"天平感宝 (749–749)",
		"天平胜宝 (749–757)",
		"天平宝字 (757–765)",
		"天平神护 (765–767)",
		"神护景云 (767–770)",
		"宝龟 (770–780)",
		"天应 (781–782)",
		"延历 (782–806)",
		"大同 (806–810)",
		"弘仁 (810–824)",
		"天长 (824–834)",
		"承和 (834–848)",
		"嘉祥 (848–851)",
		"仁寿 (851–854)",
		"齐衡 (854–857)",
		"天安 (857–859)",
		"贞观 (859–877)",
		"元庆 (877–885)",
		"仁和 (885–889)",
		"宽平 (889–898)",
		"昌泰 (898–901)",
		"延喜 (901–923)",
		"延长 (923–931)",
		"承平 (931–938)",
		"天庆 (938–947)",
		"天历 (947–957)",
		"天德 (957–961)",
		"应和 (961–964)",
		"康保 (964–968)",
		"安和 (968–970)",
		"天禄 (970–973)",
		"天延 (973–976)",
		"贞元 (976–978)",
		"天元 (978–983)",
		"永观 (983–985)",
		"宽和 (985–987)",
		"永延 (987–989)",
		"永祚 (989–990)",
		"正历 (990–995)",
		"长德 (995–999)",
		"长保 (999–1004)",
		"宽弘 (1004–1012)",
		"长和 (1012–1017)",
		"宽仁 (1017–1021)",
		"治安 (1021–1024)",
		"万寿 (1024–1028)",
		"长元 (1028–1037)",
		"长历 (1037–1040)",
		"长久 (1040–1044)",
		"宽德 (1044–1046)",
		"永承 (1046–1053)",
		"天喜 (1053–1058)",
		"康平 (1058–1065)",
		"治历 (1065–1069)",
		"延久 (1069–1074)",
		"承保 (1074–1077)",
		"正历 (1077–1081)",
		"永保 (1081–1084)",
		"应德 (1084–1087)",
		"宽治 (1087–1094)",
		"嘉保 (1094–1096)",
		"永长 (1096–1097)",
		"承德 (1097–1099)",
		"康和 (1099–1104)",
		"长治 (1104–1106)",
		"嘉承 (1106–1108)",
		"天仁 (1108–1110)",
		"天永 (1110–1113)",
		"永久 (1113–1118)",
		"元永 (1118–1120)",
		"保安 (1120–1124)",
		"天治 (1124–1126)",
		"大治 (1126–1131)",
		"天承 (1131–1132)",
		"长承 (1132–1135)",
		"保延 (1135–1141)",
		"永治 (1141–1142)",
		"康治 (1142–1144)",
		"天养 (1144–1145)",
		"久安 (1145–1151)",
		"仁平 (1151–1154)",
		"久寿 (1154–1156)",
		"保元 (1156–1159)",
		"平治 (1159–1160)",
		"永历 (1160–1161)",
		"应保 (1161–1163)",
		"长宽 (1163–1165)",
		"永万 (1165–1166)",
		"仁安 (1166–1169)",
		"嘉应 (1169–1171)",
		"承安 (1171–1175)",
		"安元 (1175–1177)",
		"治承 (1177–1181)",
		"养和 (1181–1182)",
		"寿永 (1182–1184)",
		"元历 (1184–1185)",
		"文治 (1185–1190)",
		"建久 (1190–1199)",
		"正治 (1199–1201)",
		"建仁 (1201–1204)",
		"元久 (1204–1206)",
		"建永 (1206–1207)",
		"承元 (1207–1211)",
		"建历 (1211–1213)",
		"建保 (1213–1219)",
		"承久 (1219–1222)",
		"贞应 (1222–1224)",
		"元仁 (1224–1225)",
		"嘉禄 (1225–1227)",
		"安贞 (1227–1229)",
		"宽喜 (1229–1232)",
		"贞永 (1232–1233)",
		"天福 (1233–1234)",
		"文历 (1234–1235)",
		"嘉祯 (1235–1238)",
		"历仁 (1238–1239)",
		"延应 (1239–1240)",
		"仁治 (1240–1243)",
		"宽元 (1243–1247)",
		"宝治 (1247–1249)",
		"建长 (1249–1256)",
		"康元 (1256–1257)",
		"正嘉 (1257–1259)",
		"正元 (1259–1260)",
		"文应 (1260–1261)",
		"弘长 (1261–1264)",
		"文永 (1264–1275)",
		"建治 (1275–1278)",
		"弘安 (1278–1288)",
		"正应 (1288–1293)",
		"永仁 (1293–1299)",
		"正安 (1299–1302)",
		"干元 (1302–1303)",
		"嘉元 (1303–1306)",
		"德治 (1306–1308)",
		"延庆 (1308–1311)",
		"应长 (1311–1312)",
		"正和 (1312–1317)",
		"文保 (1317–1319)",
		"元应 (1319–1321)",
		"元亨 (1321–1324)",
		"正中 (1324–1326)",
		"嘉历 (1326–1329)",
		"元德 (1329–1331)",
		"元弘 (1331–1334)",
		"建武 (1334–1336)",
		"延元 (1336–1340)",
		"兴国 (1340–1346)",
		"正平 (1346–1370)",
		"建德 (1370–1372)",
		"文中 (1372–1375)",
		"天授 (1375–1379)",
		"康历 (1379–1381)",
		"弘和 (1381–1384)",
		"元中 (1384–1392)",
		"至德 (1384–1387)",
		"嘉庆 (1387–1389)",
		"康应 (1389–1390)",
		"明德 (1390–1394)",
		"应永 (1394–1428)",
		"正长 (1428–1429)",
		"永享 (1429–1441)",
		"嘉吉 (1441–1444)",
		"文安 (1444–1449)",
		"宝德 (1449–1452)",
		"享德 (1452–1455)",
		"康正 (1455–1457)",
		"长禄 (1457–1460)",
		"宽正 (1460–1466)",
		"文正 (1466–1467)",
		"应仁 (1467–1469)",
		"文明 (1469–1487)",
		"长享 (1487–1489)",
		"延德 (1489–1492)",
		"明应 (1492–1501)",
		"文龟 (1501–1504)",
		"永正 (1504–1521)",
		"大永 (1521–1528)",
		"享禄 (1528–1532)",
		"天文 (1532–1555)",
		"弘治 (1555–1558)",
		"永禄 (1558–1570)",
		"元龟 (1570–1573)",
		"天正 (1573–1592)",
		"文禄 (1592–1596)",
		"庆长 (1596–1615)",
		"元和 (1615–1624)",
		"宽永 (1624–1644)",
		"正保 (1644–1648)",
		"庆安 (1648–1652)",
		"承应 (1652–1655)",
		"明历 (1655–1658)",
		"万治 (1658–1661)",
		"宽文 (1661–1673)",
		"延宝 (1673–1681)",
		"天和 (1681–1684)",
		"贞享 (1684–1688)",
		"元禄 (1688–1704)",
		"宝永 (1704–1711)",
		"正德 (1711–1716)",
		"享保 (1716–1736)",
		"元文 (1736–1741)",
		"宽保 (1741–1744)",
		"延享 (1744–1748)",
		"宽延 (1748–1751)",
		"宝历 (1751–1764)",
		"明和 (1764–1772)",
		"安永 (1772–1781)",
		"天明 (1781–1789)",
		"宽政 (1789–1801)",
		"享和 (1801–1804)",
		"文化 (1804–1818)",
		"文政 (1818–1830)",
		"天保 (1830–1844)",
		"弘化 (1844–1848)",
		"嘉永 (1848–1854)",
		"安政 (1854–1860)",
		"万延 (1860–1861)",
		"文久 (1861–1864)",
		"元治 (1864–1865)",
		"庆应 (1865–1868)",
		"明治",
		"大正",
		"昭和",
		"平成"
	],
	"field-minute": "分钟",
	"field-dayperiod": "上午/下午",
	"dateFormatItem-d": "d日",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "昨天",
	"dateFormatItem-h": "ah时",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "前天",
	"dateFormatItem-MMMd": "M月d日",
	"dateFormatItem-MEd": "M-dE",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "本周五",
	"field-fri-relative+1": "下周五",
	"field-day": "日",
	"field-zone": "时区",
	"dateFormatItem-y": "Gy年",
	"field-year-relative+-1": "去年",
	"field-month-relative+-1": "上个月",
	"dateFormatItem-hm": "ah:mm",
	"dateFormatItem-yyyyMd": "Gy-MM-dd",
	"field-month": "月",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "本周二",
	"field-tue-relative+1": "下周二",
	"field-mon-relative+0": "本周一",
	"field-mon-relative+1": "下周一",
	"dateFormat-short": "Gyy-MM-dd",
	"field-second": "秒钟",
	"field-sat-relative+-1": "上周六",
	"field-sun-relative+-1": "上周日",
	"field-month-relative+0": "本月",
	"field-month-relative+1": "下个月",
	"dateFormatItem-Ed": "d日E",
	"field-week": "周",
	"dateFormat-medium": "Gy年M月d日",
	"field-year-relative+0": "今年",
	"field-week-relative+-1": "上周",
	"dateFormatItem-yyyyM": "Gy-MM",
	"field-year-relative+1": "明年",
	"dateFormatItem-yyyyQQQQ": "Gy年QQQQ",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "ah:mm:ss",
	"dateFormatItem-GyMMM": "Gy年M月",
	"field-mon-relative+-1": "上周一",
	"dateFormatItem-yyyy": "Gy年",
	"field-week-relative+0": "本周",
	"field-week-relative+1": "下周"
}
//end v1.x content
);
